@@ -35,11 +35,7 @@ class CreateTorrentJob(base.JobBase):
 
     name = 'torrent'
     label = 'Torrent'
-
-    @property
-    def cache_id(self):
-        """Final segment of `content_path` and tracker :attr:`~.TrackerBase.name`"""
-        return (fs.basename(self._content_path), self._tracker.name)
+    cache_id = None
 
     def initialize(self, *, tracker, content_path):
         """
@@ -60,7 +56,13 @@ class CreateTorrentJob(base.JobBase):
 
     def execute(self):
         """Get announce URL from `tracker`, then execute torrent creation subprocess"""
-        self.add_task(self._get_announce_url())
+        if not self.ignore_cache and os.path.exists(self._torrent_path):
+            self._handle_torrent_created(self._torrent_path)
+            self.finish()
+        else:
+            self._get_announce_url_task = self.add_task(self._get_announce_url())
+            self._get_announce_url_task.add_done_callback(
+                lambda task: self._create_torrent_process(task.result()))
 
     async def _get_announce_url(self):
         self.info = 'Getting announce URL'
@@ -69,10 +71,10 @@ class CreateTorrentJob(base.JobBase):
             await self._tracker.login()
             announce_url = await self._tracker.get_announce_url()
         except errors.RequestError as e:
-            self.error(e, finish=True)
+            self.error(e)
         else:
             self.signal.emit('announce_url', announce_url)
-            self._create_torrent_process(announce_url)
+            return announce_url
         finally:
             self.info = ''
             try:
@@ -89,8 +91,8 @@ class CreateTorrentJob(base.JobBase):
                 'torrent_path' : self._torrent_path,
                 'overwrite'    : self.ignore_cache,
                 'announce'     : announce_url,
-                'source'       : self._tracker.config['source'],
-                'exclude'      : self._tracker.config['exclude'],
+                'source'       : self._tracker.options['source'],
+                'exclude'      : self._tracker.options['exclude'],
             },
             init_callback=self._handle_file_tree,
             info_callback=self._handle_progress_update,
