@@ -1,5 +1,5 @@
 """
-:class:`~.base.TrackerJobsBase` subclass
+Concrete :class:`~.base.TrackerJobsBase` subclass for bB
 """
 
 import asyncio
@@ -180,11 +180,11 @@ class BbTrackerJobs(TrackerJobsBase):
         def condition():
             if self.release_type in release_types:
                 # Job is appropriate for release type
-                if not self.monojob_attributes:
+                if not self.isolated_jobs:
                     # No jobs where singled out via CLI arguments or other
                     # means; all appropriate jobs are enabled
                     return True
-                elif job_attr in self.monojob_attributes:
+                elif job_attr in self.isolated_jobs:
                     # This particular job was singled out by the user;
                     # all other jobs are disabled
                     return True
@@ -192,10 +192,10 @@ class BbTrackerJobs(TrackerJobsBase):
         return condition
 
     @property
-    def monojob_attributes(self):
+    def isolated_jobs(self):
         """
-        Sequence of attributes (e.g. "movie_poster_job") that were singled out by
-        the user
+        Sequence of attribute names (e.g. "movie_poster_job") that were singled out
+        by the user, e.g. with a CLI argument
         """
         if self.is_movie_release:
             if self.options.get('title', False):
@@ -340,7 +340,7 @@ class BbTrackerJobs(TrackerJobsBase):
             autodetected=self.release_name.source,
             autofinish=True,
             options=(
-                {'label': 'BluRay', 'value': 'BluRay', 'regex': re.compile('^BluRay')},  # BluRay or BluRay Remux
+                {'label': 'BluRay', 'value': 'BluRay', 'regex': re.compile('BluRay')},  # [Hybrid] BluRay [Remux]
                 # {'label': 'BluRay 3D', 'value': ' ', 'regex': re.compile('^ $')},
                 # {'label': 'BluRay RC', 'value': ' ', 'regex': re.compile('^ $')},
                 # {'label': 'CAM', 'value': ' ', 'regex': re.compile('^ $')},
@@ -714,6 +714,16 @@ class BbTrackerJobs(TrackerJobsBase):
         if 'DC' in self.release_name.edition:
             return "Director's Cut"
 
+    @property
+    def release_info_theatrical_cut(self):
+        if 'Theatrical' in self.release_name.edition:
+            return 'Theatrical Cut'
+
+    @property
+    def release_info_imax(self):
+        if 'IMAX' in self.release_name.edition:
+            return 'IMAX'
+
     @property
     def release_info_extended_edition(self):
         if 'Extended' in self.release_name.edition:
@@ -790,6 +800,8 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_unrated,
             self.release_info_remastered,
             self.release_info_directors_cut,
+            self.release_info_theatrical_cut,
+            self.release_info_imax,
             self.release_info_extended_edition,
             self.release_info_anniversary_edition,
             self.release_info_criterion_edition,
@@ -883,6 +895,8 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_unrated,
             self.release_info_remastered,
             self.release_info_directors_cut,
+            self.release_info_theatrical_cut,
+            self.release_info_imax,
             self.release_info_extended_edition,
             self.release_info_anniversary_edition,
             self.release_info_criterion_edition,
@@ -1130,10 +1144,10 @@ class BbTrackerJobs(TrackerJobsBase):
     @property
     def submission_ok(self):
         """
-        `False` if :attr:`monojob_attributes` is truthy, parent implementation
+        `False` if :attr:`isolated_jobs` is truthy, parent implementation
         otherwise
         """
-        if self.monojob_attributes:
+        if self.isolated_jobs:
             return False
         else:
             return super().submission_ok
