@@ -5,6 +5,7 @@ HTTP methods with caching
 import asyncio
 import collections
 import hashlib
+import io
 import json
 import os
 
@@ -192,9 +193,9 @@ async def _request(method, url, headers={}, params={}, data={}, files={},
         raise ValueError(f'Invalid method: {method}')
 
     if isinstance(data, (bytes, str)):
-        payload = {'content': data}
+        build_request_args = {'content': data}
     else:
-        payload = {'data': data}
+        build_request_args = {'data': data}
 
     headers = {**_default_headers, **headers}
     request = _client.build_request(
@@ -203,7 +204,7 @@ async def _request(method, url, headers={}, params={}, data={}, files={},
         url=str(url),
         params=params,
         files=_open_files(files),
-        **payload,
+        **build_request_args,
     )
 
     if isinstance(user_agent, str):
@@ -260,14 +261,33 @@ def _open_files(files):
     """
     Open files for upload
 
-    :param files: Dictionary that maps field names to file paths or to 2-tuples
-        of file paths and MIME types
+    :param files: Dictionary that maps field names to file paths or
+        dictionaries. For dictionaries, these keys are used:
+
+             ``file``
+                 File path or file-like object, e.g. return value of
+                 :func:`open` or an instance of a subclass of
+                 :class:`~.io.IOBase`.
+
+             ``filename`` (optional)
+                 Name of the file that is reported to the server in the
+                 request. Defaults to :func:`~.os.path.basename` of ``file`` if
+                 ``file`` is a string, `None` otherwise.
+
+             ``mimetype`` (optional)
+                 MIME type of the file content. Guess based on ``file`` if not
+                 provided. If `None`, do not send any MIME type.
 
         Example:
 
         >>> _open_files({
         >>>     "image": "path/to/foo.jpg",
-        >>>     "document": ("path/to/bar", "text/plain"),
+        >>>     "document": {"file": "path/to/bar", "mimetype": "text/plain"},
+        >>>     "data": {
+        >>>         "file": io.IOBytes(b'binary data'),
+        >>>         "filename": "binary.data",
+        >>>         "mimetype": "application/octet-stream",
+        >>>      },
         >>> })
 
     :return: See https://www.python-httpx.org/advanced/#multipart-file-encoding
@@ -277,22 +297,31 @@ def _open_files(files):
     opened = {}
     for fieldname, fileinfo in files.items():
         if isinstance(fileinfo, str):
-            opened[fieldname] = (
-                os.path.basename(fileinfo),     # File name
-                _get_fileobj(fileinfo),         # File handle
-            )
-        elif isinstance(fileinfo, collections.abc.Sequence) and len(fileinfo) == 2:
-            opened[fieldname] = (
-                os.path.basename(fileinfo[0]),  # File name
-                _get_fileobj(fileinfo[0]),      # File handle
-                fileinfo[1],                    # MIME type
-            )
+            filename = os.path.basename(fileinfo)
+            fileobj = _get_file_object(fileinfo)
+            opened[fieldname] = (filename, fileobj)
+
+        elif isinstance(fileinfo, collections.abc.Mapping):
+            if isinstance(fileinfo['file'], str):
+                filename = fileinfo.get('filename', os.path.basename(fileinfo['file']))
+                fileobj = _get_file_object(fileinfo['file'])
+            elif isinstance(fileinfo['file'], io.IOBase):
+                filename = fileinfo.get('filename', None)
+                fileobj = fileinfo['file']
+            else:
+                raise RuntimeError(f'Invalid "file" value in fileinfo: {fileinfo["file"]!r}')
+            mimetype = fileinfo.get('mimetype', False)
+            if mimetype is False:
+                opened[fieldname] = (filename, fileobj)
+            else:
+                opened[fieldname] = (filename, fileobj, mimetype)
+
         else:
-            raise RuntimeError(f'Invalid file: {fileinfo}')
+            raise RuntimeError(f'Invalid fileinfo: {fileinfo}')
+
     return opened
 
-
-def _get_fileobj(filepath):
+def _get_file_object(filepath):
     """
     Open `filepath` and return the file object
 
@@ -355,7 +384,7 @@ def _cache_file(method, url, params={}):
 
     return os.path.join(
         cache_directory or constants.CACHE_DIRPATH,
-        make_filename(method, url, params_str),
+        fs.sanitize_filename(make_filename(method, url, params_str)),
     )
 
 
