@@ -2,10 +2,10 @@
 API for querying services like IMDb
 """
 
-from .. import subclasses, submodules
+from .. import CaseInsensitiveString, subclasses, submodules
 from . import imdb, tmdb, tvmaze
 from .base import WebDbApiBase
-from .common import Query, SearchResult
+from .common import Person, Query, SearchResult
 
 
 def webdbs():
@@ -19,7 +19,7 @@ def webdb(name, **kwargs):
 
     :param str name: Name of the DB. A subclass of :class:`.WebDbApiBase` with
         the same :attr:`~.WebDbApiBase.name` must exist in one of this package's
-        submodules
+        submodules.
     :param kwargs: All keyword arguments are passed to the subclass specified by
         `name`
 
@@ -30,4 +30,9 @@ def webdb(name, **kwargs):
     for cls in webdbs():
         if cls.name == name:
             return cls(**kwargs)
-    raise ValueError(f'Unsupported web DB: {name}')
+    raise ValueError(f'Unsupported web database: {name}')
+
+
+def webdb_names():
+    """Return sequence of valid `name` arguments for :func:`.webdb`"""
+    return sorted(CaseInsensitiveString(cls.name) for cls in webdbs())
